@@ -1,4 +1,12 @@
-jomo1con<- function(Y, X=matrix(1,nrow(Y),1), beta.start=matrix(0,ncol(X),ncol(Y)), l1cov.start=diag(1,ncol(Y)), l1cov.prior=diag(1,ncol(Y)), nburn=100, nbetween=100, nimp=5,output=1, out.iter=10) {
+jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NULL, nburn=100, nbetween=100, nimp=5,output=1, out.iter=10) {
+  if (nimp<2) {
+    nimp=2
+    cat("Minimum number of imputations:2. For single imputation using function jomo1con.MCMCchain\n")
+  }
+  if (is.null(X)) X=matrix(1,nrow(Y),1)
+  if (is.null(beta.start)) beta.start=matrix(0,ncol(X),ncol(Y))
+  if (is.null(l1cov.start)) l1cov.start=diag(1,ncol(beta.start))
+  if (is.null(l1cov.prior)) l1cov.prior=diag(1,ncol(beta.start))
   for (i in 1:ncol(X)) {
     if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
   }
