@@ -106,5 +106,14 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
   if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
   if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
   colnames(imp)<-c(colnamy,colnamx,colnamz,"clus","id","Imputation")
+  dimnames(betapost)[1] <- list(colnamx)
+  dimnames(betapost)[2] <- list(colnamy)
+  dimnames(omegapost)[1] <- list(colnamy)
+  dimnames(omegapost)[2] <- list(colnamy)
+  colnamcovu<-paste(colnamy,rep(colnamz,each=ncol(omegapost)),sep="*")
+  dimnames(covupost)[1] <- list(colnamcovu)
+  dimnames(covupost)[2] <- list(colnamcovu)
+  dimnames(upostall)[1]<-list(levels(clus))
+  dimnames(upostall)[2]<-list(colnamcovu)
   return(list("finimp"=imp,"collectbeta"=betapost,"collectomega"=omegapost,"collectu"=upostall, "collectcovu"=covupost))
 }
\ No newline at end of file
