@@ -1,5 +1,14 @@
 jomo1ranmixhr <-
-function(Y.con, Y.cat, Y.numcat, X=matrix(1,nrow(Y.cat),1), Z=matrix(1,nrow(Y.cat),1), clus, beta.start=matrix(0,ncol(X),(ncol(Y.con)+(sum(Y.numcat)-length(Y.numcat)))), u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=diag(1,ncol(beta.start)), l2cov.prior=NULL, nburn=100, nbetween=100, nimp=5,a=ncol(beta.start),meth="random", output=1, out.iter=10) {
+function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL, l2cov.prior=NULL, nburn=100, nbetween=100, nimp=5, a=NULL, meth="random", output=1, out.iter=10) {
+  if (nimp<2) {
+    nimp=2
+    cat("Minimum number of imputations:2. For single imputation using function jomo1ranmixhr.MCMCchain\n")
+  }
+  if (is.null(X)) X=matrix(1,nrow(Y.cat),1) 
+  if (is.null(Z)) Z=matrix(1,nrow(Y.cat),1)
+  if (is.null(beta.start)) beta.start=matrix(0,ncol(X),(ncol(Y.con)+(sum(Y.numcat)-length(Y.numcat))))
+  if (is.null(l1cov.prior)) l1cov.prior=diag(1,ncol(beta.start))
+  if (is.null(a)) a=ncol(beta.start)
   clus<-factor(unlist(clus))
   previous_levels_clus<-levels(clus)
   levels(clus)<-0:(nlevels(clus)-1)
@@ -149,7 +158,9 @@ function(Y.con, Y.cat, Y.numcat, X=matrix(1,nrow(Y.cat),1), Z=matrix(1,nrow(Y.ca
     imp[,(ncol(Y.con)+i)]<-as.factor(imp[,(ncol(Y.con)+i)]) 
     levels(imp[,(ncol(Y.con)+i)])<-previous_levels[[i]]
   }
+  imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)]<-factor(imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)])
   levels(imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)])<-previous_levels_clus
+  clus<-factor(clus)
   levels(clus)<-previous_levels_clus
   for (j in 1:(ncol(Y.con))) {
     imp[,j]=as.numeric(imp[,j])
